@@ -11,6 +11,8 @@ from pyflakes.messages import UndefinedExport, UndefinedName, UnusedImport
 from pyprojroot import here
 
 common_statements: Dict[str, str] = {
+    "ABC": "from abc import ABC",
+    "abstractmethod": "from abc import abstractmethod",
     "BaseModel": "from pydantic import BaseModel  # noqa: E0611",
     "BeautifulSoup": "from bs4 import BeautifulSoup",
     "call": "from unittest.mock import call",
@@ -26,10 +28,12 @@ common_statements: Dict[str, str] = {
     "LogCaptureFixture": "from _pytest.logging import LogCaptureFixture",
     "Mock": "from unittest.mock import Mock",
     "ModelFactory": "from pydantic_factories import ModelFactory",
+    "Path": "from pathlib import Path",
     "patch": "from unittest.mock import patch",
     "StringIO": "from io import StringIO",
     "suppress": "from contextlib import suppress",
     "TempdirFactory": "from _pytest.tmpdir import TempdirFactory",
+    "tz": "from dateutil import tz",
     "YAMLError": "from yaml import YAMLError",
 }
 
@@ -162,7 +166,7 @@ class SourceCode:  # noqa: R090
             self.typing.append(source_lines[typing_start_line])
             typing_start_line += 1
             for line in source_lines[typing_start_line:]:
-                if not re.match(r"^\s+.*", line):
+                if not re.match(r"^\s+.*", line) and line != "":
                     break
                 self.typing.append(line)
 
@@ -361,6 +365,15 @@ class SourceCode:  # noqa: R090
         except KeyError:
             return None
 
+    def _get_additional_statements(self) -> Dict[str, str]:
+        """When parsing to the cli via --config-file the config becomes nested."""
+        common_statements = self.config.get("common_statements")
+        if common_statements:
+            return common_statements
+        return (
+            self.config.get("tool", {}).get("autoimport", {}).get("common_statements")
+        )
+
     def _find_package_in_common_statements(self, name: str) -> Optional[str]:
         """Search in the common statements the object name.
 
@@ -371,8 +384,9 @@ class SourceCode:  # noqa: R090
             import_string
         """
         local_common_statements = common_statements.copy()
-        if "common_statements" in self.config:
-            local_common_statements.update(self.config["common_statements"])
+        additional_statements = self._get_additional_statements()
+        if additional_statements:
+            local_common_statements.update(additional_statements)
 
         if name in local_common_statements:
             return local_common_statements[name]
@@ -427,11 +441,20 @@ class SourceCode:  # noqa: R090
             ):
                 # fmt: on
                 line_number = self.imports.index(line)
+                # Remove the object name from the multiline imports
                 while line_number + 1 < len(self.imports):
                     line_number += 1
                     if re.match(fr"\s*?{object_name},?", self.imports[line_number]):
                         self.imports.pop(line_number)
-                        return
+                        break
+
+                # Remove the whole import if there is no other object loaded
+                if re.match(r"\s*from .* import", self.imports[line_number - 1]) \
+                        and self.imports[line_number] == ')':
+                    self.imports.pop(line_number)
+                    self.imports.pop(line_number - 1)
+
+                return
 
 
 def extract_package_objects(name: str) -> Dict[str, str]:
